<h1 align=center>NEORICK</h1>

<div align=center>
  
  ![Project Status](https://img.shields.io/badge/status-Em%20andamento-yellow)
  ![versão](https://img.shields.io/badge/versão-1.0.0-important)
  
</div>

> [!WARNING]
> O uso dos arquivos deste projeto é delimitado para <strong>fins de estudo</strong>. Qualquer outra ação está estrictamente proibida.

> Caso ainda não tenha o Python instalado, baixe [aqui.](https://www.python.org/downloads)

# Requisitos

1. Python 3.10 ou superior
2. Git

# Utilização

Caso queira rodar este script na sua máquina, siga os passos abaixo:

1. Clone o repositório de entre nele

```sh
git clone https://github.com/Rickzinho3/neorick.git
cd neorick
```

2. Instale as deoendências

```sh
poetry install
```

# Extra

Caso queira que o `Neorich` seja executado no seu powershell, siga os seguintes passos:

Abra o `Powershell` e digite o comando `notepad $PROFILE`

> [!NOTE]
> Caso você não tenha um perfil, irá aparecer uma mensagem para você criar, basta confirmar.

Depois de abrir o seu perfil, coloque o seguinte comando no bloco de notas:

`python <caminho-do-script>`

E substitua `<caminho-do-script>` pelo caminho onde você salvou o arquivo. Depois é só salvar e aproveiatr!

<br>

<p align=center>J. Henrique &copy; 2025. Todos os direitos reservados.</p>
